

.. _sphx_glr_content_user_guide_auto_examples_1single:

1 | Single-Set Analysis
=======================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates Extended EOF (EEOF) analysis on xarray tutorial data. EEOF analysis, ...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eeof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eeof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Extented EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial, we&#x27;ll walk through how to perform a Complex EOF analysis on the zonal and mer...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_complex_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_complex_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Complex EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EOF analysis in T-mode maximises the spatial variance.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eof-tmode_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eof-tmode.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">EOF analysis (T-mode)</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We demonstrate how to execute a Hilbert EOF analysis [1]_ [2]_ [3]_. This method extends tradit...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_hilbert_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_hilbert_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Hilbert EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates the application of sparse PCA [1]_ to sea surface temperature data. S...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eof-smode_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eof-smode.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Sparse PCA</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This tutorial illustrates the application of Extended EOF (EEOF) analysis to isolate and remove...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eeof_trend_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eeof_trend.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Removing nonlinear trends with EEOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Multivariate EOF analysis.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_multivariate-eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_multivariate-eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Multivariate EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Multivariate EOF analysis with additional Varimax rotation.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_mreof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_mreof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Varimax-rotated Multivariate EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EOF (Empirical Orthogonal Function) analysis is commonly used in climate science, interpreting ...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_rotated_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_rotated_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Rotated EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Weighted EOF analysis (in S-mode) maximises the temporal variance considering each gridpoint wi...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_weighted-eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_weighted-eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Weighted EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="TIn this demonstration, we&#x27;ll apply GWPCA to a dataset detailing the chemical compositions of s...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_gwpca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_gwpca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Geographically weighted PCA</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /content/user_guide/auto_examples/1single/plot_eeof
   /content/user_guide/auto_examples/1single/plot_complex_eof
   /content/user_guide/auto_examples/1single/plot_eof-tmode
   /content/user_guide/auto_examples/1single/plot_hilbert_eof
   /content/user_guide/auto_examples/1single/plot_eof-smode
   /content/user_guide/auto_examples/1single/plot_eeof_trend
   /content/user_guide/auto_examples/1single/plot_multivariate-eof
   /content/user_guide/auto_examples/1single/plot_mreof
   /content/user_guide/auto_examples/1single/plot_rotated_eof
   /content/user_guide/auto_examples/1single/plot_weighted-eof
   /content/user_guide/auto_examples/1single/plot_gwpca

